@@ -1,7 +1,7 @@
 
 package OODoc::Format::Html;
 use vars '$VERSION';
-$VERSION = '0.09';
+$VERSION = '0.10';
 use base 'OODoc::Format';
 
 use strict;
@@ -17,7 +17,7 @@ use File::Basename qw/basename dirname/;
 use File::Copy     'copy';
 use POSIX          'strftime';
 
-use Text::MagicTemplate;
+use Template::Magic;
 
 
 #-------------------------------------------
@@ -222,7 +222,7 @@ sub expandTemplate($$)
               }, $loc
             );
     }
-    elsif(-f $loc) { push @result, $loc, $defaults }
+    elsif(-f $loc) { push @result, $loc => $defaults }
     else { croak "ERROR: cannot find template source $loc." }
 
     @result;
@@ -595,7 +595,7 @@ sub format(@)
 {   my ($self, %args) = @_;
     my $output    = delete $args{output};
 
-    my %permitted;
+    my %permitted = ();
     while(my ($tag, $method) = each %producers)
     {   $permitted{$tag}
           = sub { my $zone = shift;
@@ -603,11 +603,10 @@ sub format(@)
                 };
     }
 
-    my $template  = Text::MagicTemplate->new
-     ( { -markers   => 'HTML'
-       , -behaviors => 'HTML'
-       , -lookups   => \%permitted
-       }
+    my $template  = Template::Magic->new
+     ( markers   => 'HTML'
+     , behaviors => 'HTML'
+     , lookups   => [ \%permitted ]
      );
 
     my $created = $template->output($args{template});
@@ -684,13 +683,13 @@ sub templateName($$)
        or die "ERROR: not a manual, so no name for $args->{template}\n";
 
     my $chapter = $manual->chapter('NAME')
-       or die "ERROR: cannot find chapter NAME in manual $manual";
+       or die "ERROR: cannot find chapter NAME in manual ",$manual->source,"\n";
 
     my $descr   = $chapter->description;
 
     return $1 if $descr =~ m/^\s*\S+\s*\-\s*(.*?)\s*$/;
    
-    die "ERROR: chapter NAME in manual $manual has illegal shape";
+    die "ERROR: chapter NAME in manual $manual has illegal shape\n";
 }
 
 #-------------------------------------------
@@ -754,7 +753,8 @@ sub templateChapter($$)
     croak "ERROR: chapter without name in template"
        unless defined $name;
 
-    my $manual  = $args->{manual} or confess;
+    my $manual  = $args->{manual};
+    defined $manual or confess;
     my $chapter = $manual->chapter($name) or return '';
 
     my $out     = '';
