@@ -1,7 +1,7 @@
 
 package OODoc::Manual;
 use vars '$VERSION';
-$VERSION = '0.09';
+$VERSION = '0.10';
 use base 'OODoc::Object';
 
 use strict;
@@ -127,14 +127,15 @@ sub name()
 {   my $self    = shift;
     return $self->{OP_name} if defined $self->{OP_name};
 
-    my $chapter = $self->chapter('NAME') or return ();
-    my $text    = $chapter->description;
+    my $chapter = $self->chapter('NAME')
+        or die "ERROR: No chapter NAME in manual ".$self->source."\n";
 
-    die "ERROR: No name in manual ".$self->source."\n"
-       unless $text =~ m/^\s*(\S*)\s*\-\s*/;
+    my $text   = $chapter->description || '';
+    $text =~ m/^\s*(\S+)\s*\-\s/
+        or die "ERROR: The NAME chapter does not have the right format in "
+             , $self->source, "\n";
 
-    $self->{OP_name} = $1
-   
+    $self->{OP_name} = $1;
 }
 
 
@@ -257,7 +258,7 @@ sub inherited($) {$_[0]->name ne $_[1]->manual->name}
 
 sub ownSubroutines
 {   my $self = shift;
-    my $me   = $self->name;
+    my $me   = $self->name || return 0;
     grep {not $self->inherited($_)} $self->subroutines;
 }
 
@@ -459,9 +460,9 @@ sub mostDetailedLocation($)
 
 sub stats()
 {   my $self     = shift;
+    my $chapters = $self->chapters || return;
     my $subs     = $self->ownSubroutines;
     my $diags    = $self->diagnostics;
-    my $chapters = $self->chapters;
     my $examples = $self->examples;
 
     my $manual   = $self->name;
